from .base import BBDataset, TemporalDataset, PredictionTemporalDataset
from brainbox.datasets.implementations.singer import BBCWild
from brainbox.datasets.implementations.taylor import (
    Natural,
    MouseNat,
    HumanNat,
    PatchNatural,
)
